==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/web/kotlin/WebAppFtpAllowed.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.web.kotlin

import com.pulumi.core.Output
import com.pulumi.kotlin.KotlinCustomResource
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.ResourceMapper
import com.pulumi.kotlin.options.CustomResourceOptions
import com.pulumi.kotlin.options.CustomResourceOptionsBuilder
import com.pulumi.resources.Resource
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit

/**
 * Builder for [WebAppFtpAllowed].
 */
@PulumiTagMarker
public class WebAppFtpAllowedResourceBuilder internal constructor() {
    public var name: String? = null

    public var args: WebAppFtpAllowedArgs = WebAppFtpAllowedArgs()

    public var opts: CustomResourceOptions = CustomResourceOptions()

    /**
     * @param name The _unique_ name of the resulting resource.
     */
    public fun name(`value`: String) {
        this.name = value
    }

    /**
     * @param block The arguments to use to populate this resource's properties.
     */
    public suspend fun args(block: suspend WebAppFtpAllowedArgsBuilder.() -> Unit) {
        val builder = WebAppFtpAllowedArgsBuilder()
        block(builder)
        this.args = builder.build()
    }

    /**
     * @param block A bag of options that control this resource's behavior.
     */
    public suspend fun opts(block: suspend CustomResourceOptionsBuilder.() -> Unit) {
        this.opts = com.pulumi.kotlin.options.opts(block)
    }

    internal fun build(): WebAppFtpAllowed {
        val builtJavaResource = com.pulumi.azurenative.web.WebAppFtpAllowed(
            this.name,
            this.args.toJava(),
            this.opts.toJava(),
        )
        return WebAppFtpAllowed(builtJavaResource)
    }
}

/**
 * Publishing Credentials Policies parameters.
 * Azure REST API version: 2022-09-01.
 * Other available API versions: 2019-08-01, 2020-06-01, 2020-09-01, 2020-10-01, 2020-12-01, 2021-01-01, 2021-01-15, 2021-02-01, 2021-03-01, 2022-03-01, 2023-01-01.
 * ## Example Usage
 * ### Update FTP Allowed
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var webAppFtpAllowed = new AzureNative.Web.WebAppFtpAllowed("webAppFtpAllowed", new()
 *     {
 *         Allow = true,
 *         Name = "testSite",
 *         ResourceGroupName = "rg",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/web/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := web.NewWebAppFtpAllowed(ctx, "webAppFtpAllowed", &web.WebAppFtpAllowedArgs{
 * 			Allow:             pulumi.Bool(true),
 * 			Name:              pulumi.String("testSite"),
 * 			ResourceGroupName: pulumi.String("rg"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.web.WebAppFtpAllowed;
 * import com.pulumi.azurenative.web.WebAppFtpAllowedArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var webAppFtpAllowed = new WebAppFtpAllowed("webAppFtpAllowed", WebAppFtpAllowedArgs.builder()
 *             .allow(true)
 *             .name("testSite")
 *             .resourceGroupName("rg")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:web:WebAppFtpAllowed myresource1 /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Web/sites/{name}/basicPublishingCredentialsPolicies/ftp
 * ```
 */
public class WebAppFtpAllowed internal constructor(
    override val javaResource: com.pulumi.azurenative.web.WebAppFtpAllowed,
) : KotlinCustomResource(javaResource, WebAppFtpAllowedMapper) {
    /**
     * <code>true</code> to allow access to a publishing method; otherwise, <code>false</code>.
     */
    public val allow: Output<Boolean>
        get() = javaResource.allow().applyValue({ args0 -> args0 })

    /**
     * Kind of resource.
     */
    public val kind: Output<String>?
        get() = javaResource.kind().applyValue({ args0 -> args0.map({ args0 -> args0 }).orElse(null) })

    /**
     * Resource Name.
     */
    public val name: Output<String>
        get() = javaResource.name().applyValue({ args0 -> args0 })

    /**
     * Resource type.
     */
    public val type: Output<String>
        get() = javaResource.type().applyValue({ args0 -> args0 })
}

public object WebAppFtpAllowedMapper : ResourceMapper<WebAppFtpAllowed> {
    override fun supportsMappingOfType(javaResource: Resource): Boolean =
        com.pulumi.azurenative.web.WebAppFtpAllowed::class == javaResource::class

    override fun map(javaResource: Resource): WebAppFtpAllowed = WebAppFtpAllowed(
        javaResource as
            com.pulumi.azurenative.web.WebAppFtpAllowed,
    )
}

/**
 * @see [WebAppFtpAllowed].
 * @param name The _unique_ name of the resulting resource.
 * @param block Builder for [WebAppFtpAllowed].
 */
public suspend fun webAppFtpAllowed(
    name: String,
    block: suspend WebAppFtpAllowedResourceBuilder.() -> Unit,
): WebAppFtpAllowed {
    val builder = WebAppFtpAllowedResourceBuilder()
    builder.name(name)
    block(builder)
    return builder.build()
}

/**
 * @see [WebAppFtpAllowed].
 * @param name The _unique_ name of the resulting resource.
 */
public fun webAppFtpAllowed(name: String): WebAppFtpAllowed {
    val builder = WebAppFtpAllowedResourceBuilder()
    builder.name(name)
    return builder.build()
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/web/kotlin/WebAppFtpAllowed.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.web.kotlin

import com.pulumi.core.Output
import com.pulumi.kotlin.KotlinCustomResource
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.ResourceMapper
import com.pulumi.kotlin.options.CustomResourceOptions
import com.pulumi.kotlin.options.CustomResourceOptionsBuilder
import com.pulumi.resources.Resource
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit

/**
 * Builder for [WebAppFtpAllowed].
 */
@PulumiTagMarker
public class WebAppFtpAllowedResourceBuilder internal constructor() {
    public var name: String? = null

    public var args: WebAppFtpAllowedArgs = WebAppFtpAllowedArgs()

    public var opts: CustomResourceOptions = CustomResourceOptions()

    /**
     * @param name The _unique_ name of the resulting resource.
     */
    public fun name(`value`: String) {
        this.name = value
    }

    /**
     * @param block The arguments to use to populate this resource's properties.
     */
    public suspend fun args(block: suspend WebAppFtpAllowedArgsBuilder.() -> Unit) {
        val builder = WebAppFtpAllowedArgsBuilder()
        block(builder)
        this.args = builder.build()
    }

    /**
     * @param block A bag of options that control this resource's behavior.
     */
    public suspend fun opts(block: suspend CustomResourceOptionsBuilder.() -> Unit) {
        this.opts = com.pulumi.kotlin.options.CustomResourceOptions.opts(block)
    }

    internal fun build(): WebAppFtpAllowed {
        val builtJavaResource = com.pulumi.azurenative.web.WebAppFtpAllowed(
            this.name,
            this.args.toJava(),
            this.opts.toJava(),
        )
        return WebAppFtpAllowed(builtJavaResource)
    }
}

/**
 * Publishing Credentials Policies parameters.
 * Azure REST API version: 2022-09-01.
 * Other available API versions: 2019-08-01, 2020-06-01, 2020-09-01, 2020-10-01, 2020-12-01, 2021-01-01, 2021-01-15, 2021-02-01, 2021-03-01, 2022-03-01, 2023-01-01.
 * ## Example Usage
 * ### Update FTP Allowed
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var webAppFtpAllowed = new AzureNative.Web.WebAppFtpAllowed("webAppFtpAllowed", new()
 *     {
 *         Allow = true,
 *         Name = "testSite",
 *         ResourceGroupName = "rg",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/web/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := web.NewWebAppFtpAllowed(ctx, "webAppFtpAllowed", &web.WebAppFtpAllowedArgs{
 * 			Allow:             pulumi.Bool(true),
 * 			Name:              pulumi.String("testSite"),
 * 			ResourceGroupName: pulumi.String("rg"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.web.WebAppFtpAllowed;
 * import com.pulumi.azurenative.web.WebAppFtpAllowedArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var webAppFtpAllowed = new WebAppFtpAllowed("webAppFtpAllowed", WebAppFtpAllowedArgs.builder()
 *             .allow(true)
 *             .name("testSite")
 *             .resourceGroupName("rg")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:web:WebAppFtpAllowed myresource1 /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Web/sites/{name}/basicPublishingCredentialsPolicies/ftp
 * ```
 */
public class WebAppFtpAllowed internal constructor(
    override val javaResource: com.pulumi.azurenative.web.WebAppFtpAllowed,
) : KotlinCustomResource(javaResource, WebAppFtpAllowedMapper) {
    /**
     * <code>true</code> to allow access to a publishing method; otherwise, <code>false</code>.
     */
    public val allow: Output<Boolean>
        get() = javaResource.allow().applyValue({ args0 -> args0 })

    /**
     * Kind of resource.
     */
    public val kind: Output<String>?
        get() = javaResource.kind().applyValue({ args0 -> args0.map({ args0 -> args0 }).orElse(null) })

    /**
     * Resource Name.
     */
    public val name: Output<String>
        get() = javaResource.name().applyValue({ args0 -> args0 })

    /**
     * Resource type.
     */
    public val type: Output<String>
        get() = javaResource.type().applyValue({ args0 -> args0 })
}

public object WebAppFtpAllowedMapper : ResourceMapper<WebAppFtpAllowed> {
    override fun supportsMappingOfType(javaResource: Resource): Boolean =
        com.pulumi.azurenative.web.WebAppFtpAllowed::class == javaResource::class

    override fun map(javaResource: Resource): WebAppFtpAllowed = WebAppFtpAllowed(
        javaResource as
            com.pulumi.azurenative.web.WebAppFtpAllowed,
    )
}

/**
 * @see [WebAppFtpAllowed].
 * @param name The _unique_ name of the resulting resource.
 * @param block Builder for [WebAppFtpAllowed].
 */
public suspend fun webAppFtpAllowed(
    name: String,
    block: suspend WebAppFtpAllowedResourceBuilder.() -> Unit,
): WebAppFtpAllowed {
    val builder = WebAppFtpAllowedResourceBuilder()
    builder.name(name)
    block(builder)
    return builder.build()
}

/**
 * @see [WebAppFtpAllowed].
 * @param name The _unique_ name of the resulting resource.
 */
public fun webAppFtpAllowed(name: String): WebAppFtpAllowed {
    val builder = WebAppFtpAllowedResourceBuilder()
    builder.name(name)
    return builder.build()
}
